@@ -1,7 +1,7 @@
 """Optimization module."""
 from copy import deepcopy
 from itertools import repeat
-from typing import MutableSequence, Sequence
+from typing import MutableSequence
 
 import attr
 import numpy as np
@@ -56,7 +56,7 @@ class OptimizationHandler:
         num_tool_parameters = np.sum(self.tool_mask)
 
         # extract vector segments
-        segments = np.split(  # type: ignore
+        segments = np.split(
             vector, [num_kc_parameters, num_kc_parameters + num_tool_parameters]
         )
         kc_segment = segments[0]
@@ -91,8 +91,8 @@ class OptimizationHandler:
 def optimize_accuracy(
     optimization_vector: npt.NDArray[np.float64],
     handler: OptimizationHandler,
-    qs: Sequence[npt.NDArray[np.float64]],
-    positions: Sequence[npt.NDArray[np.float64]],
+    qs: npt.NDArray[np.float64],
+    positions: npt.NDArray[np.float64],
 ) -> npt.NDArray[np.float64]:
     """Fitness function for accuracy optimization."""
     handler.apply_optimization_vector(optimization_vector)
@@ -107,13 +107,13 @@ def compute_absolute_error(
     pose = robot.fk(q)
     actual_position = position_from_matrix(pose)
     error = position - actual_position  # type: npt.NDArray[np.float64]
-    result = float(np.linalg.norm(error))  # type: ignore
+    result = float(np.linalg.norm(error))
     return result
 
 
 def compute_absolute_errors(
-    qs: Sequence[npt.NDArray[np.float64]],
-    positions: Sequence[npt.NDArray[np.float64]],
+    qs: npt.NDArray[np.float64],
+    positions: npt.NDArray[np.float64],
     robot: Robot,
 ) -> npt.NDArray[np.float64]:
     """
@@ -123,7 +123,7 @@ def compute_absolute_errors(
     :param positions: Array of Cartesian positions, shape=(n-poses, 3)
     :param robot: Robot model
     """
-    return np.fromiter(  # type: ignore
+    return np.fromiter(
         map(compute_absolute_error, qs, positions, repeat(robot)), dtype=np.float64
     )
 
@@ -141,10 +141,10 @@ def compute_relative_error(
     actual_position_a = position_from_matrix(pose_a)
     actual_position_b = position_from_matrix(pose_b)
 
-    actual_distance = actual_position_a - actual_position_b  # type: float
-    actual_distance = np.linalg.norm(actual_distance)  # type: ignore
+    actual_distance = actual_position_a - actual_position_b
+    scalar_distance = np.linalg.norm(actual_distance)
 
-    error = float(np.linalg.norm(distance - actual_distance))  # type: ignore
+    error = float(np.linalg.norm(distance - scalar_distance))
 
     return error
 
@@ -156,7 +156,7 @@ def compute_relative_errors(
     robot: Robot,
 ) -> npt.NDArray[np.float64]:
     """Compute the relative errors of a given set of position combinations."""
-    return np.fromiter(  # type: ignore
+    return np.fromiter(
         map(compute_relative_error, qs_a, qs_b, distances, repeat(robot)),
         dtype=np.float64,
     )
