@@ -83,7 +83,7 @@ class Robot(Sized):
         # matrix multiply through transforms
         pose = np.eye(4, dtype=float)
         for t in transforms:
-            pose = np.dot(pose, t)  # type: ignore
+            pose = np.dot(pose, t)
 
         return pose
 
@@ -160,7 +160,7 @@ class Robot(Sized):
         j_tr = np.zeros((6, 6), dtype=float)
         j_tr[:3, :3] = rotation
         j_tr[3:, 3:] = rotation
-        j_w = np.dot(j_tr, j_fl)  # type: ignore
+        j_w = np.dot(j_tr, j_fl)
 
         return typing.cast(npt.NDArray[np.float64], j_w)
 
@@ -192,9 +192,7 @@ class Robot(Sized):
             current_link = self.kinematic_chain.links[i]
             p = q[i]
             current_link_transform = current_link.transform(p)
-            current_transform = np.dot(  # type: ignore
-                current_link_transform, current_transform
-            )
+            current_transform = np.dot(current_link_transform, current_transform)
 
         return jacobian_flange
 
@@ -235,11 +233,11 @@ class Robot(Sized):
 
             # calculate force applied to current link
             rotation = transform[:3, :3]
-            force = np.dot(rotation, force)  # type: ignore
+            force = np.dot(rotation, force)
 
             # calculate moment applied to current link
             q = transform[:3, -1]
-            moment = np.dot(rotation, moment) + np.cross(q, force)  # type: ignore
+            moment = np.dot(rotation, moment) + np.cross(q, force)
 
             # append z-component as joint torque
             joint_torques.append(moment[-1])
